@@ -8,7 +8,7 @@ use List::MoreUtils qw(natatime);
 use MARC::Field;
 use Method::Signatures;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use vars qw( @EXPORT_OK );
 use Exporter 'import';
@@ -45,6 +45,8 @@ func naco_from_string( Str $s, Bool :$keep_first_comma ) {
         my $i = index $s, ',';
         $s =~ s/,/ /g;
         $s =~ s/^((?:.){$i})\s/$1,/;
+        # always strip off a trailing comma, even if it's the only one
+        $s =~ s/,$//;
     }
     else {
         $s =~ s/,/ /g;
